# Summary

- [Introduction](./introduction.md)
- [Getting started](./getting_started.md)
- [Case study: Memory leak analysis](./memory_leak_analysis.md)
- [Common issues](./common_issues.md)
- [Configuring the profiler](./configuration.md)
- [API reference](./api_reference.md)
   - [Globally available functions](./api_reference/globals.md)
      - [`allocations`](./api_reference/globals/allocations.md)
      - [`maps`](./api_reference/globals/maps.md)
      - [`data`](./api_reference/globals/data.md)
      - [`graph`](./api_reference/globals/graph.md)
      - [`info`](./api_reference/globals/info.md)
      - [`load`](./api_reference/globals/load.md)
      - [`println`](./api_reference/globals/println.md)
      - [`h`](./api_reference/globals/h.md)
      - [`m`](./api_reference/globals/m.md)
      - [`s`](./api_reference/globals/s.md)
      - [`ms`](./api_reference/globals/ms.md)
      - [`us`](./api_reference/globals/us.md)
      - [`kb`](./api_reference/globals/kb.md)
      - [`mb`](./api_reference/globals/mb.md)
      - [`gb`](./api_reference/globals/gb.md)
      - [`argv`](./api_reference/globals/argv.md)
      - [`chdir`](./api_reference/globals/chdir.md)
      - [`dirname`](./api_reference/globals/dirname.md)
      - [`exit`](./api_reference/globals/exit.md)
      - [`mkdir_p`](./api_reference/globals/mkdir_p.md)
   - [`Allocation`](./api_reference/Allocation.md)
      - [`allocated_at`](./api_reference/Allocation/allocated_at.md)
      - [`backtrace`](./api_reference/Allocation/backtrace.md)
      - [`deallocated_at`](./api_reference/Allocation/deallocated_at.md)
   - [`AllocationList`](./api_reference/AllocationList.md)
      - [`\-` (operator)](./api_reference/AllocationList/op_minus.md)
      - [`\+` (operator)](./api_reference/AllocationList/op_plus.md)
      - [`&` (operator)](./api_reference/AllocationList/op_and.md)
      - [`[]` (operator)](./api_reference/AllocationList/op_square_brackets.md)
      - [`group_by_backtrace`](./api_reference/AllocationList/group_by_backtrace.md)
      - [`len`](./api_reference/AllocationList/len.md)
      - [`only_address_at_least`](./api_reference/AllocationList/only_address_at_least.md)
      - [`only_address_at_most`](./api_reference/AllocationList/only_address_at_most.md)
      - [`only_alive_at`](./api_reference/AllocationList/only_alive_at.md)
      - [`only_alive_for_at_least`](./api_reference/AllocationList/only_alive_for_at_least.md)
      - [`only_alive_for_at_most`](./api_reference/AllocationList/only_alive_for_at_most.md)
      - [`only_allocated_after_at_least`](./api_reference/AllocationList/only_allocated_after_at_least.md)
      - [`only_allocated_until_at_most`](./api_reference/AllocationList/only_allocated_until_at_most.md)
      - [`only_backtrace_length_at_least`](./api_reference/AllocationList/only_backtrace_length_at_least.md)
      - [`only_backtrace_length_at_most`](./api_reference/AllocationList/only_backtrace_length_at_most.md)
      - [`only_chain_alive_for_at_least`](./api_reference/AllocationList/only_chain_alive_for_at_least.md)
      - [`only_chain_alive_for_at_most`](./api_reference/AllocationList/only_chain_alive_for_at_most.md)
      - [`only_chain_length_at_least`](./api_reference/AllocationList/only_chain_length_at_least.md)
      - [`only_chain_length_at_most`](./api_reference/AllocationList/only_chain_length_at_most.md)
      - [`only_deallocated_after_at_least`](./api_reference/AllocationList/only_deallocated_after_at_least.md)
      - [`only_deallocated_until_at_most`](./api_reference/AllocationList/only_deallocated_until_at_most.md)
      - [`only_first_size_larger_or_equal`](./api_reference/AllocationList/only_first_size_larger_or_equal.md)
      - [`only_first_size_larger`](./api_reference/AllocationList/only_first_size_larger.md)
      - [`only_first_size_smaller_or_equal`](./api_reference/AllocationList/only_first_size_smaller_or_equal.md)
      - [`only_first_size_smaller`](./api_reference/AllocationList/only_first_size_smaller.md)
      - [`only_from_maps`](./api_reference/AllocationList/only_from_maps.md)
      - [`only_group_allocations_at_least`](./api_reference/AllocationList/only_group_allocations_at_least.md)
      - [`only_group_allocations_at_most`](./api_reference/AllocationList/only_group_allocations_at_most.md)
      - [`only_group_interval_at_least`](./api_reference/AllocationList/only_group_interval_at_least.md)
      - [`only_group_interval_at_most`](./api_reference/AllocationList/only_group_interval_at_most.md)
      - [`only_group_leaked_allocations_at_least`](./api_reference/AllocationList/only_group_leaked_allocations_at_least.md)
      - [`only_group_leaked_allocations_at_most`](./api_reference/AllocationList/only_group_leaked_allocations_at_most.md)
      - [`only_group_max_total_usage_first_seen_at_least`](./api_reference/AllocationList/only_group_max_total_usage_first_seen_at_least.md)
      - [`only_group_max_total_usage_first_seen_at_most`](./api_reference/AllocationList/only_group_max_total_usage_first_seen_at_most.md)
      - [`only_jemalloc`](./api_reference/AllocationList/only_jemalloc.md)
      - [`only_larger_or_equal`](./api_reference/AllocationList/only_larger_or_equal.md)
      - [`only_larger`](./api_reference/AllocationList/only_larger.md)
      - [`only_last_size_larger_or_equal`](./api_reference/AllocationList/only_last_size_larger_or_equal.md)
      - [`only_last_size_larger`](./api_reference/AllocationList/only_last_size_larger.md)
      - [`only_last_size_smaller_or_equal`](./api_reference/AllocationList/only_last_size_smaller_or_equal.md)
      - [`only_last_size_smaller`](./api_reference/AllocationList/only_last_size_smaller.md)
      - [`only_leaked_or_deallocated_after`](./api_reference/AllocationList/only_leaked_or_deallocated_after.md)
      - [`only_leaked`](./api_reference/AllocationList/only_leaked.md)
      - [`only_matching_backtraces`](./api_reference/AllocationList/only_matching_backtraces.md)
      - [`only_not_jemalloc`](./api_reference/AllocationList/only_not_jemalloc.md)
      - [`only_not_matching_backtraces`](./api_reference/AllocationList/only_not_matching_backtraces.md)
      - [`only_not_passing_through_function`](./api_reference/AllocationList/only_not_passing_through_function.md)
      - [`only_not_passing_through_source`](./api_reference/AllocationList/only_not_passing_through_source.md)
      - [`only_passing_through_function`](./api_reference/AllocationList/only_passing_through_function.md)
      - [`only_passing_through_source`](./api_reference/AllocationList/only_passing_through_source.md)
      - [`only_ptmalloc_from_main_arena`](./api_reference/AllocationList/only_ptmalloc_from_main_arena.md)
      - [`only_ptmalloc_mmaped`](./api_reference/AllocationList/only_ptmalloc_mmaped.md)
      - [`only_ptmalloc_not_from_main_arena`](./api_reference/AllocationList/only_ptmalloc_not_from_main_arena.md)
      - [`only_ptmalloc_not_mmaped`](./api_reference/AllocationList/only_ptmalloc_not_mmaped.md)
      - [`only_smaller_or_equal`](./api_reference/AllocationList/only_smaller_or_equal.md)
      - [`only_smaller`](./api_reference/AllocationList/only_smaller.md)
      - [`only_temporary`](./api_reference/AllocationList/only_temporary.md)
      - [`save_as_flamegraph`](./api_reference/AllocationList/save_as_flamegraph.md)
      - [`save_as_graph`](./api_reference/AllocationList/save_as_graph.md)
   - [`AllocationGroupList`](./api_reference/AllocationGroupList.md)
      - [`(iterator)`](./api_reference/AllocationGroupList/op_iterator.md)
      - [`[]` (operator)](./api_reference/AllocationGroupList/op_square_brackets.md)
      - [`len`](./api_reference/AllocationGroupList/len.md)
      - [`only_all_leaked`](./api_reference/AllocationGroupList/only_all_leaked.md)
      - [`only_count_at_least`](./api_reference/AllocationGroupList/only_count_at_least.md)
      - [`sort_by_count_ascending`](./api_reference/AllocationGroupList/sort_by_count_ascending.md)
      - [`sort_by_count_descending`](./api_reference/AllocationGroupList/sort_by_count_descending.md)
      - [`sort_by_count`](./api_reference/AllocationGroupList/sort_by_count.md)
      - [`sort_by_size_ascending`](./api_reference/AllocationGroupList/sort_by_size_ascending.md)
      - [`sort_by_size_descending`](./api_reference/AllocationGroupList/sort_by_size_descending.md)
      - [`sort_by_size`](./api_reference/AllocationGroupList/sort_by_size.md)
      - [`take`](./api_reference/AllocationGroupList/take.md)
      - [`ungroup`](./api_reference/AllocationGroupList/ungroup.md)
   - [`Backtrace`](./api_reference/Backtrace.md)
      - [`strip`](./api_reference/Backtrace/strip.md)
   - [`Data`](./api_reference/Data.md)
      - [`allocations`](./api_reference/Data/allocations.md)
      - [`runtime`](./api_reference/Data/runtime.md)
   - [`Duration`](./api_reference/Duration.md)
      - [`\+` (operator)](./api_reference/Duration/op_plus.md)
      - [`\-` (operator)](./api_reference/Duration/op_minus.md)
      - [`\*` (operator)](./api_reference/Duration/op_multiply.md)
   - [`Graph`](./api_reference/Graph.md)
      - [`add`](./api_reference/Graph/add.md)
      - [`only_non_empty_series`](./api_reference/Graph/only_non_empty_series.md)
      - [`save_each_series_as_flamegraph`](./api_reference/Graph/save_each_series_as_flamegraph.md)
      - [`save_each_series_as_graph`](./api_reference/Graph/save_each_series_as_graph.md)
      - [`save`](./api_reference/Graph/save.md)
      - [`show_address_space`](./api_reference/Graph/show_address_space.md)
      - [`show_deallocations`](./api_reference/Graph/show_deallocations.md)
      - [`show_live_allocations`](./api_reference/Graph/show_live_allocations.md)
      - [`show_memory_usage`](./api_reference/Graph/show_memory_usage.md)
      - [`show_new_allocations`](./api_reference/Graph/show_new_allocations.md)
      - [`show_rss`](./api_reference/Graph/show_rss.md)
      - [`trim_left`](./api_reference/Graph/trim_left.md)
      - [`trim_right`](./api_reference/Graph/trim_right.md)
      - [`trim`](./api_reference/Graph/trim.md)
      - [`start_at`](./api_reference/Graph/start_at.md)
      - [`end_at`](./api_reference/Graph/end_at.md)
      - [`with_gradient_color_scheme`](./api_reference/Graph/with_gradient_color_scheme.md)
      - [`without_axes`](./api_reference/Graph/without_axes.md)
      - [`without_grid`](./api_reference/Graph/without_grid.md)
      - [`without_legend`](./api_reference/Graph/without_legend.md)
   - [`Map`](./api_reference/Map.md)
      - [`allocated_at`](./api_reference/Map/allocated_at.md)
      - [`backtrace`](./api_reference/Map/backtrace.md)
      - [`deallocated_at`](./api_reference/Map/deallocated_at.md)
   - [`MapList`](./api_reference/MapList.md)
      - [`len`](./api_reference/MapList/len.md)
      - [`only_address_at_least`](./api_reference/MapList/only_address_at_least.md)
      - [`only_address_at_most`](./api_reference/MapList/only_address_at_most.md)
      - [`only_alive_at`](./api_reference/MapList/only_alive_at.md)
      - [`only_alive_for_at_least`](./api_reference/MapList/only_alive_for_at_least.md)
      - [`only_alive_for_at_most`](./api_reference/MapList/only_alive_for_at_most.md)
      - [`only_allocated_after_at_least`](./api_reference/MapList/only_allocated_after_at_least.md)
      - [`only_allocated_until_at_most`](./api_reference/MapList/only_allocated_until_at_most.md)
      - [`only_backtrace_length_at_least`](./api_reference/MapList/only_backtrace_length_at_least.md)
      - [`only_backtrace_length_at_most`](./api_reference/MapList/only_backtrace_length_at_most.md)
      - [`only_bytehound`](./api_reference/MapList/only_bytehound.md)
      - [`only_deallocated_after_at_least`](./api_reference/MapList/only_deallocated_after_at_least.md)
      - [`only_deallocated_until_at_most`](./api_reference/MapList/only_deallocated_until_at_most.md)
      - [`only_executable`](./api_reference/MapList/only_executable.md)
      - [`only_jemalloc`](./api_reference/MapList/only_jemalloc.md)
      - [`only_larger`](./api_reference/MapList/only_larger.md)
      - [`only_larger_or_equal`](./api_reference/MapList/only_larger_or_equal.md)
      - [`only_leaked`](./api_reference/MapList/only_leaked.md)
      - [`only_leaked_or_deallocated_after`](./api_reference/MapList/only_leaked_or_deallocated_after.md)
      - [`only_matching_backtraces`](./api_reference/MapList/only_matching_backtraces.md)
      - [`only_matching_deallocation_backtraces`](./api_reference/MapList/only_matching_deallocation_backtraces.md)
      - [`only_not_bytehound`](./api_reference/MapList/only_not_bytehound.md)
      - [`only_not_executable`](./api_reference/MapList/only_not_executable.md)
      - [`only_not_jemalloc`](./api_reference/MapList/only_not_jemalloc.md)
      - [`only_not_matching_backtraces`](./api_reference/MapList/only_not_matching_backtraces.md)
      - [`only_not_matching_deallocation_backtraces`](./api_reference/MapList/only_not_matching_deallocation_backtraces.md)
      - [`only_not_passing_through_function`](./api_reference/MapList/only_not_passing_through_function.md)
      - [`only_not_passing_through_source`](./api_reference/MapList/only_not_passing_through_source.md)
      - [`only_not_readable`](./api_reference/MapList/only_not_readable.md)
      - [`only_not_writable`](./api_reference/MapList/only_not_writable.md)
      - [`only_passing_through_function`](./api_reference/MapList/only_passing_through_function.md)
      - [`only_passing_through_source`](./api_reference/MapList/only_passing_through_source.md)
      - [`only_peak_rss_at_least`](./api_reference/MapList/only_peak_rss_at_least.md)
      - [`only_peak_rss_at_most`](./api_reference/MapList/only_peak_rss_at_most.md)
      - [`only_readable`](./api_reference/MapList/only_readable.md)
      - [`only_smaller`](./api_reference/MapList/only_smaller.md)
      - [`only_smaller_or_equal`](./api_reference/MapList/only_smaller_or_equal.md)
      - [`only_temporary`](./api_reference/MapList/only_temporary.md)
      - [`only_writable`](./api_reference/MapList/only_writable.md)
      - [`\-` (operator)](./api_reference/MapList/op_minus.md)
      - [`\+` (operator)](./api_reference/MapList/op_plus.md)
      - [`&` (operator)](./api_reference/MapList/op_and.md)
      - [`[]` (operator)](./api_reference/MapList/op_square_brackets.md)
